@@ -12,7 +12,7 @@ use Search::Tools::HiLiter;
 use Search::Tools::Transliterate;
 use Search::Tools::XML;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 # accessors that every object should inherit from its parent
 our @Accessors = qw(
@@ -23,7 +23,11 @@ our @Accessors = qw(
     ignore_last_char
     stemmer
     phrase_delim
+    ignore_case
     debug
+    locale
+    charset
+    lang
     
     );
 
@@ -158,7 +162,11 @@ The following common accessors are inherited by every module in Search::Tools:
     ignore_last_char
     stemmer
     phrase_delim
+    ignore_case
     debug
+    locale
+    charset
+    lang
 
 See each module's documentation for more details.
 
