@@ -4,11 +4,11 @@ require 5.008;
 use strict;
 use warnings;
 use Carp;
-#use Data::Dumper;      # just for debugging
+
+#use Data::Dump qw/dump/;      # just for debugging
 use Encode;
 
-our $VERSION = '0.01';
-
+our $VERSION = '0.02';
 
 =pod
 
@@ -36,10 +36,24 @@ by Markus Kuhn http://www.cl.cam.ac.uk/~mgk25/.
 
 Create new instance.
 
+=head2 is_valid_utf8( I<text> )
+
+Returns true if I<text> is a valid sequence of UTF-8 bytes. It does B<not>
+check if the internal Perl C<utf8> flag is set or not.
+
+
+=head2 is_ascii( I<text> )
+
+If I<text> contains no bytes above 127, then returns true (1). Otherwise,
+returns false (0). Used by convert() internally to check I<text> prior
+to transliterating.
+
 =head2 convert( I<text> )
 
-Returns I<text> converted with all single bytes, transliterated according
-to %Map.
+Returns UTF-8 I<text> converted with all single bytes, transliterated according
+to %Map. Will croak if I<text> is not valid UTF-8, so if in doubt, check first with
+is_valid_utf8().
+
 
 =head1 VARIABLES
 
@@ -76,13 +90,10 @@ same terms as Perl itself.
 
 =head1 SEE ALSO
 
-Search::Tools, Unicode::Map, Encode
+Search::Tools, Unicode::Map, Encode, Test::utf8
 
 =cut
 
-
-
-
 # build map
 our %Map = ();
 while (<DATA>)
@@ -98,10 +109,10 @@ for (128 .. 255)
     $Map{chr($_)} = chr($_);
 }
 
-
-# A Regexp string to match valid UTF8 bytes
+# A Regexp string to match valid UTF-8 bytes
 # this info comes from page 78 of "The Unicode Standard 4.0"
 # published by the Unicode Consortium
+# cribbed from Test::utf8 methinks...
 our $valid_utf8_regexp = <<EOE;
         [\x{00}-\x{7f}]
       | [\x{c2}-\x{df}][\x{80}-\x{bf}]
@@ -114,7 +125,6 @@ our $valid_utf8_regexp = <<EOE;
       |         \x{f4} [\x{80}-\x{8f}][\x{80}-\x{bf}][\x{80}-\x{bf}]
 EOE
 
-
 sub _Utag_to_chr
 {
     my $t = shift;
@@ -142,14 +152,60 @@ sub _init
     @$self{keys %extra} = values %extra;
 }
 
+# cribbed from Test::utf8
+sub _invalid_sequence_at_byte($)
+{
+    my $string = shift;
+
+    # examine the bytes that make up the string (not the chars)
+    # by turning off the utf8 flag (no, use bytes doesn't
+    # work, we're dealing with a regexp)
+    Encode::_utf8_off($string);
+
+    # work out the index of the first non matching byte
+    my $result = $string =~ m/^($valid_utf8_regexp)*/ogx;
+
+    # if we matched all the string return the empty list
+    my $pos = pos $string || 0;
+    if ($pos == length($string))
+    {
+        Encode::_utf8_on($string);  # do we really need this??
+        return;
+    }
+
+    # otherwise return the position we found
+    return $pos;
+}
+
+sub is_valid_utf8
+{
+    my $self = shift;
+    my $buf  = shift;
+    return defined(_invalid_sequence_at_byte($buf)) ? 0 : 1;
+}
+
+sub is_ascii
+{
+    my $self = shift;
+    my $buf  = shift;
+    return $buf =~ m/[^\x{00}-\x{7f}]/o ? 0 : 1;
+}
+
 sub convert
 {
     my $self   = shift;
     my $buf    = shift;
     my $newbuf = '';
-    
+
     # don't bother unless we have non-ascii bytes
-    return $buf unless $buf =~ m/[^\x{00}-\x{7f}]/o;
+    return $buf if $self->is_ascii($buf);
+
+    # make sure we've got valid UTF-8 to start with
+    my $pos = _invalid_sequence_at_byte($buf);
+    if (defined($pos))
+    {
+        croak "bad UTF-8 byte at $pos";
+    }
 
     Encode::_utf8_off($buf);
 
@@ -181,7 +237,7 @@ sub convert
 
 1;
 
-# map taken directly from 
+# map taken directly from
 # http://www.cl.cam.ac.uk/~mgk25/download/transtab.tar.gz
 # by Markus Kuhn
 
